#!/bin/bash

#==============================================================================
# epages-common.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_INSTALL_VERSION

[[ $EPAGES_INSTALL_VERSION = latest ]] && EPAGES_INSTALL_VERSION=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export update_epages_environment
export link_epages link_etc etc_default

. $(dirname $0)/fun-wi.sh
export set_wi

. $(dirname $0)/fun-repoedit.sh
export enable_repo

. $(dirname $0)/fun-linux.sh
export initial_file chkconfig_do

. $(dirname $0)/fun-host.sh
export set_etc_hosts

. $(dirname $0)/fun-account.sh
export add_user add_to_cron_group chown_epages chgrp_epages

. $(dirname $0)/fun-pkg.sh
export pkg_instance

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-common-pre
#..............................................................................
epages-common-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-common-pre INSTANCE RPM_VERSION'
    echo 'description: pre-uninstallation tasks of epages-common package'
    echo 'example: epages-common-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  [[ $INSTANCE = first ]] || return 0

  add_user -u WS_RUN -g WS -s nologin
  add_user -u J -g AS
  add_user -u AS_RUN -g AS -G WS
  add_user -u WS -g WS
  add_user -u AS -g AS -G WS

  # see EPG-9706
  add_to_cron_group AS WS AS_RUN
  return 0
}

#..............................................................................
# epages-common-post
#..............................................................................
epages-common-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-common-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-common package'
    echo 'example: epages-common-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  update_epages_environment -i "$1"

  link_epages $RPM_INSTALL_PREFIX

  link_etc

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  [[ -f $ETC_DEFAULT ]] || { ls -l $ETC_DEFAULT; exit 1; } 
  . $ETC_DEFAULT

  enable_repo 0 graphviz-.+ nodejs-.+ atrpms packman-multimedia

  initial_file $EPAGES_CONFIG

  set_etc_hosts AS RR WS J MYSQL

  set_wi EXCEPTION_HOST

  chgrp_epages -R WS "$EPAGES_LOG/" "$EPAGES_WEBROOT/" "$EPAGES_SHARED"/Monitor/ "$EPAGES"/WebAdapter/
  chown_epages -R AS "$EPAGES_LOG/"
  chown_epages -R AS_RUN "$EPAGES_WEBROOT/" "$EPAGES_STORES/" "$EPAGES_STATIC/"
  chown_epages AS "$EPAGES_CONFIG/" "$EPAGES_CONFIG"/{{Database,Cartridges}.d{,/*.conf*},DataCache.conf*,*.db} 2>/dev/null

  return 0
}

#..............................................................................
# epages-common-preun
#..............................................................................
epages-common-preun() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-common-preun INSTANCE RPM_VERSION'
    echo 'description: preun-uninstallation tasks of epages-common package'
    echo 'example: epages-common-preun 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  chkconfig_do --del epages6

  return 0
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)   epages-common-pre $2 $3 ; exit $? ;;
  post)  epages-common-post  $2 $3 ; exit $? ;;
  preun) epages-common-preun $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
