#!/bin/bash

#==============================================================================
# epages-j.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_INSTALL_VERSION

[[ $EPAGES_INSTALL_VERSION = latest ]] && EPAGES_INSTALL_VERSION=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-account.sh
export add_user chown_epages

. $(dirname $0)/fun-epages.sh
export create_etc_default update_epages_environment link_epages link_etc

. $(dirname $0)/fun-repoedit.sh
export enable_repo

. $(dirname $0)/fun-j.sh
export update_epagesj_conf start_epagesj

. $(dirname $0)/fun-java.sh
export start_mongodb

. $(dirname $0)/fun-pkg.sh
export pkg_instance

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-j-pre
#..............................................................................
epages-j-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-j-pre INSTANCE RPM_VERSION'
    echo 'description: pre-uninstallation tasks of epages-j package'
    echo 'example: epages-j-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  if [[ $INSTANCE = first ]] ; then
    add_user -u AS -g AS -G WS
    add_user -u J -g AS -G WS
  fi

  for i in epages-solr epages-solr-slave epagesj ; do
    /etc/init.d/$i status >/dev/null 2>&1 && /etc/init.d/$i stop
  done

  rm -rf "${RPM_INSTALL_PREFIX:-/srv/epages}"/eproot/j/work/*
  [[ -z $EPAGESJ_KEEP_CORES ]] && rm -rf "${RPM_INSTALL_PREFIX:-/srv/epages}"/eproot/j/cores/*

  return 0
}

#..............................................................................
# epages-j-post
#..............................................................................
epages-j-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-j-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-j package'
    echo 'example: epages-j-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  create_etc_default epagesj.ept

  update_epages_environment -i "$1"

  link_epages $RPM_INSTALL_PREFIX

  link_etc default

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  [[ -f $ETC_DEFAULT ]] || { ls -l $ETC_DEFAULT; exit 1; } 
  . $ETC_DEFAULT

  [[ $INSTANCE = first ]] && enable_repo 0 10gen

  update_epagesj_conf

  chown_epages -R J "${EPAGESJ:-/srv/epages/eproot/j}/"

  start_mongodb

  start_epagesj

  return 0
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)   epages-j-pre $2 $3 ; exit $? ;;
  post)  epages-j-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
