#!/bin/bash

#==============================================================================
# epages-mysqld.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_INSTALL_VERSION

[[ $EPAGES_INSTALL_VERSION = latest ]] && EPAGES_INSTALL_VERSION=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-pkg.sh
export pkg_instance

. $(dirname $0)/fun-linux.sh
export chkconfig_do

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-mysqld-post
#..............................................................................
epages-mysqld-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-mysqld-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-mysqld package'
    echo 'example: epages-mysqld-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  [[ $INSTANCE = first ]] || return 0

  local EPAGES_MYSQLD=mysqld
  [[ -w /etc/init.d/mysql ]] && EPAGES_MYSQLD=mysql
  local RUN_SCRIPT=/etc/init.d/$EPAGES_MYSQLD

  [[ -w $RUN_SCRIPT ]] || return 0

  chkconfig_do --del $EPAGES_MYSQLD
  if ! grep -q 'chkconfig: 235' $RUN_SCRIPT ; then
    sed -i 's/\(chkconfig:\) -/\1 235/' $(readlink -qf $RUN_SCRIPT)
  fi
  chmod 755 $RUN_SCRIPT
  chkconfig_do --add $EPAGES_MYSQLD
  /etc/init.d/$EPAGES_MYSQLD start

  "${RPM_INSTALL_PREFIX:-/srv/epages}"/eproot/Setup/SetupMySQL.sh

  return $?
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  post) epages-mysqld-post  $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
