#!/bin/bash

#==============================================================================
# epages-release.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_INSTALL_VERSION

[[ $EPAGES_INSTALL_VERSION = latest ]] && EPAGES_INSTALL_VERSION=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export get_cartridge_version internal_version

. $(dirname $0)/fun-repoedit.sh
export enable_repo update_3rdparty_repos restore_3rdparty_repos
export link_yum2zypper unlink_yum2zypper update_repo_arch

. $(dirname $0)/fun-pkg.sh
export pkg_instance pkg_installed

. $(dirname $0)/fun-httpd.sh
export backup_httpd_confd

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-release-post
#..............................................................................
epages-release-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-release-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-release package'
    echo 'example: epages-release-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  [[ -f /etc/debian_version ]] && return 0

  local CORE_VERSION=$(get_cartridge_version Core)
  [[ -n ${CORE_VERSION//[0-9.]/} ]] && CORE_VERSION=
  local INTERNAL_VERSION=${CORE_VERSION:+$(internal_version $CORE_VERSION)}

  local BAK=$(backup_httpd_confd native epages)
  [[ -n $BAK ]] && echo "Creating: $BAK"

  local SH_SCRIPT='#!/bin/sh
while [ -d /proc/$1 ] || ps auxwww | egrep -q "(zypper .*up|yum .*up|rpm .*U).*[e]pages-release"
do echo -n . ; sleep 1 ; done
echo
[ -f /etc/debian_version ] || rpm -qa | grep -qi b1d28320 || rpm --import /etc/pki/rpm-gpg/RPM-GPG-KEY-epages'
  local RUN_SH_SCRIPT
  if [[ $INSTANCE = first ]] ; then
    /var/epages/SetRepository.sh -r "$EPAGES_REPO" -X -i
    RUN_SH_SCRIPT="exit 0"
  elif [[ ${INTERNAL_VERSION:-0} -lt 6017005 && -z $SKIP_UPDATE_REPO ]] ; then
    /var/epages/SetRepository.sh -r "$EPAGES_REPO" -X -i
    RUN_SH_SCRIPT='
if [ -f /etc/redhat-release ] ; then
  yum --enablerepo="epages-*" --disablerepo "epages*-6.*" clean metadata 2>/dev/null
elif [ -f /etc/SuSE-release ] ; then
  ( zypper clean -m ; zypper refresh ) 2>/dev/null
elif [ -f /etc/debian_version ] ; then
  apt-get -y update
fi'
  else
    update_repo_arch setup base arch
  fi
  if [[ -n $RUN_SH_SCRIPT ]] ; then
    # can't change existing config files when rpm is running
    echo -e "$SH_SCRIPT\n$RUN_SH_SCRIPT" > /tmp/SetRepository-f.sh.~$$~
    chmod 755 /tmp/SetRepository-f.sh.~$$~
    /tmp/SetRepository-f.sh.~$$~ $$ > /tmp/SetRepository-f.sh.~$$~.log 2>&1 &
  fi

  update_3rdparty_repos

  enable_repo -e 0 empty update >/dev/null

  if pkg_installed epages-common ; then
    enable_repo -e 0 setup base >/dev/null
  elif [[ -z $CORE_VERSION ]] ; then
    enable_repo -e 1 setup base >/dev/null
  fi

  link_yum2zypper

  [[ -f /etc/SuSE-release ]] && cp -p /var/epages/mongod /etc/init.d
  cp -lf /var/epages/delete-epages.SH /var/epages/delete-epages.sh

  return 0
}

#..............................................................................
# epages-release-preun
#..............................................................................
epages-release-preun() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-release-preun INSTANCE RPM_VERSION'
    echo 'description: pre-uninstallation tasks of epages-release package'
    echo 'example: epages-release-preun 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=${EPAGES_INSTALL_VERSION:-$2}

  [[ -f /etc/debian_version ]] && return 0

  unlink_yum2zypper

  if [[ $INSTANCE = last ]] ; then
    # reset %config(noreplace)
    mv /etc/sysconfig/epages6.rpmsave /etc/sysconfig/epages6 2>/dev/null
    mv /var/epages/mongod.rpmsave /var/epages/mongod 2>/dev/null
    restore_3rdparty_repos
    rm -f /etc/yum.repos.d/*epages-{setup,update,empty}*
  fi

  return 0
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  post)  epages-release-post  $2 $3 ; exit $? ;;
  preun) epages-release-preun $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
